import React, { Suspense, lazy } from 'react';
import ReactDOM from 'react-dom/client';
import { createBrowserRouter, RouterProvider } from 'react-router-dom';
import ScrollToTop from './components/ScrollToTop';
import App from './App.jsx';
import './index.css';

// Existing pages
const SavannahWebDesign = lazy(() => import('./pages/SavannahWebDesign'));
const ContactPage = lazy(() => import('./pages/ContactPage'));
const AboutPage = lazy(() => import('./pages/AboutPage'));
const PricingPage = lazy(() => import('./pages/PricingPage'));
const WordPressDevelopment = lazy(() => import('./pages/WordPressDevelopment'));
const ShopifyDevelopment = lazy(() => import('./pages/ShopifyDevelopment'));
const PortfolioPage = lazy(() => import('./pages/PortfolioPage.jsx'));
const HorseRidingWebDesigner = lazy(() => import('./pages/HorseRidingWebDesigner'));

// Service pages
const SEOServices = lazy(() => import('./pages/SEOServices'));
const WebsiteMaintenance = lazy(() => import('./pages/WebsiteMaintenance'));
const WebsiteSecurity = lazy(() => import('./pages/WebsiteSecurity'));

// Industry pages
const RealEstateWebDesign = lazy(() => import('./pages/RealEstateWebDesign'));
const HealthcareWebDesign = lazy(() => import('./pages/HealthcareWebDesign'));
const EcommerceWebDesign = lazy(() => import('./pages/EcommerceWebDesign'));
const HospitalityWebDesign = lazy(() => import('./pages/HospitalityWebDesign'));
const ProfessionalServicesWebDesign = lazy(() => import('./pages/ProfessionalServicesWebDesign'));
const RetailRestaurantWebDesign = lazy(() => import('./pages/RetailRestaurantWebDesign'));

// Location pages
const DowntownSavannahWebDesign = lazy(() => import('./pages/DowntownSavannahWebDesign'));
const TybeeIslandWebDesign = lazy(() => import('./pages/TybeeIslandWebDesign'));
const RichmondHillWebDesign = lazy(() => import('./pages/RichmondHillWebDesign'));
const PoolerWebDesign = lazy(() => import('./pages/PoolerWebDesign'));
const GeorgetownWebDesign = lazy(() => import('./pages/GeorgetownWebDesign'));
const LandingsWebDesign = lazy(() => import('./pages/LandingsWebDesign'));
const SavannahSmallBusinessWebDesign = lazy(() => import('./pages/SavannahSmallBusinessWebDesign'));

// Legal pages
const PrivacyPolicy = lazy(() => import('./pages/PrivacyPolicy'));
const TermsOfService = lazy(() => import('./pages/TermsOfService'));

const withSuspense = (Component) => (
  <>
    <ScrollToTop />
    <Suspense fallback={<div className="p-4 text-center">Loading...</div>}>
      <Component />
    </Suspense>
  </>
);

const router = createBrowserRouter([
  {
    path: "/",
    element: (
      <>
        <ScrollToTop />
        <App />
      </>
    ),
  },
  {
    path: "/contact",
    element: withSuspense(ContactPage),
  },
  {
    path: "/about",
    element: withSuspense(AboutPage),
  },
  {
    path: "/pricing",
    element: withSuspense(PricingPage),
  },
  {
    path: "/portfolio",
    element: withSuspense(PortfolioPage),
  },
  {
    path: "/horse-riding-web-designer",
    element: withSuspense(HorseRidingWebDesigner),
  },
  
  // Services
  {
    path: "/services/wordpress-development",
    element: withSuspense(WordPressDevelopment),
  },
  {
    path: "/services/shopify-development",
    element: withSuspense(ShopifyDevelopment),
  },
  {
    path: "/services/seo-services",
    element: withSuspense(SEOServices),
  },
  {
    path: "/services/website-maintenance",
    element: withSuspense(WebsiteMaintenance),
  },
  {
    path: "/services/website-security",
    element: withSuspense(WebsiteSecurity),
  },
  
  // Industries
  {
    path: "/industries/real-estate-web-design",
    element: withSuspense(RealEstateWebDesign),
  },
  {
    path: "/industries/healthcare-web-design",
    element: withSuspense(HealthcareWebDesign),
  },
  {
    path: "/industries/ecommerce-web-design",
    element: withSuspense(EcommerceWebDesign),
  },
  {
    path: "/industries/hospitality-web-design",
    element: withSuspense(HospitalityWebDesign),
  },
  {
    path: "/industries/professional-services-web-design",
    element: withSuspense(ProfessionalServicesWebDesign),
  },
  {
    path: "/industries/retail-restaurant-web-design",
    element: withSuspense(RetailRestaurantWebDesign),
  },
  
  // Service Areas
  {
    path: "/savannah-web-design",
    element: withSuspense(SavannahWebDesign),
  },
  {
    path: "/downtown-savannah-web-design",
    element: withSuspense(DowntownSavannahWebDesign),
  },
  {
    path: "/tybee-island-web-design",
    element: withSuspense(TybeeIslandWebDesign),
  },
  {
    path: "/richmond-hill-web-design",
    element: withSuspense(RichmondHillWebDesign),
  },
  {
    path: "/pooler-web-design",
    element: withSuspense(PoolerWebDesign),
  },
  {
    path: "/georgetown-web-design",
    element: withSuspense(GeorgetownWebDesign),
  },
  {
    path: "/landings-web-design",
    element: withSuspense(LandingsWebDesign),
  },
  {
    path: "/savannah-small-business-web-design",
    element: withSuspense(SavannahSmallBusinessWebDesign),
  },
  {
    path: "/savannah-small-business-web-designer",
    element: withSuspense(SavannahWebDesign),
  },
  
  // Legal
  {
    path: "/privacy-policy",
    element: withSuspense(PrivacyPolicy),
  },
  {
    path: "/terms-of-service",
    element: withSuspense(TermsOfService),
  },
]);

ReactDOM.createRoot(document.getElementById('root')).render(
  <React.StrictMode>
    <RouterProvider router={router} />
  </React.StrictMode>,
);
